==> members-facade-1.0.2-20190110.085121-8-sources.jar: com/bizvane/members/facade/models/po/MbrCustomEntryPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrCustomEntryPO implements Serializable {

	/**
	 * 只读. . mbr_custom_entry_id
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "mbrCustomEntryId", required = false, example = "")
	private Long mbrCustomEntryId;
	/**
	 * 只读. 微信电子会员卡id. mbr_meber_card_id
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "微信电子会员卡id", name = "mbrMeberCardId", required = false, example = "")
	private Long mbrMeberCardId;
	/**
	 * 只读. 自定义入口名称. entry_name
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "自定义入口名称", name = "entryName", required = false, example = "")
	private String entryName;
	/**
	 * 只读. 自定义入口url地址. entry_url
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "自定义入口url地址", name = "entryUrl", required = false, example = "")
	private String entryUrl;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名. create_user_name
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建时间. create_date
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人名. modified_user_name
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人名", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间. modified_date
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public Long getMbrCustomEntryId() {
		return mbrCustomEntryId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setMbrCustomEntryId(Long mbrCustomEntryId) {
		this.mbrCustomEntryId = mbrCustomEntryId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public Long getMbrMeberCardId() {
		return mbrMeberCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setMbrMeberCardId(Long mbrMeberCardId) {
		this.mbrMeberCardId = mbrMeberCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public String getEntryName() {
		return entryName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setEntryName(String entryName) {
		this.entryName = entryName == null ? null : entryName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public String getEntryUrl() {
		return entryUrl;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setEntryUrl(String entryUrl) {
		this.entryUrl = entryUrl == null ? null : entryUrl.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-08 10:20:38
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
}

==> members-facade-2.1.2-20201228.071652-21-sources.jar: com/bizvane/members/facade/models/po/MbrCustomEntryPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrCustomEntryPO implements Serializable {

	/**
	 * 只读. . mbr_custom_entry_id
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "mbrCustomEntryId", required = false, example = "")
	private Long mbrCustomEntryId;
	/**
	 * 只读. 微信电子会员卡id. mbr_meber_card_id
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "微信电子会员卡id", name = "mbrMeberCardId", required = false, example = "")
	private Long mbrMeberCardId;
	/**
	 * 只读. 自定义入口名称. entry_name
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "自定义入口名称", name = "entryName", required = false, example = "")
	private String entryName;
	/**
	 * 只读. 自定义入口url地址. entry_url
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "自定义入口url地址", name = "entryUrl", required = false, example = "")
	private String entryUrl;
	/**
	 * 只读. 点击跳转：0=站内链接;1=网页链接. redirect
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "点击跳转：0=站内链接;1=网页链接", name = "redirect", required = false, example = "")
	private String redirect;
	/**
	 * 只读. 创建人id. create_user_id
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. 创建人名. create_user_name
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建人名", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. 创建时间. create_date
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. 修改人id. modified_user_id
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. 修改人名. modified_user_name
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改人名", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. 修改时间. modified_date
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. 数据有效性：1=有效；0=无效. valid
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	@io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public Long getMbrCustomEntryId() {
		return mbrCustomEntryId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setMbrCustomEntryId(Long mbrCustomEntryId) {
		this.mbrCustomEntryId = mbrCustomEntryId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public Long getMbrMeberCardId() {
		return mbrMeberCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setMbrMeberCardId(Long mbrMeberCardId) {
		this.mbrMeberCardId = mbrMeberCardId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public String getEntryName() {
		return entryName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setEntryName(String entryName) {
		this.entryName = entryName == null ? null : entryName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public String getEntryUrl() {
		return entryUrl;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setEntryUrl(String entryUrl) {
		this.entryUrl = entryUrl == null ? null : entryUrl.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public String getRedirect() {
		return redirect;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setRedirect(String redirect) {
		this.redirect = redirect == null ? null : redirect.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-01-15 13:48:07
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
}
